open Okweb

module type S = sig
  (** Attaches the following route handlers to the app:
      - [GET /looksok.css]
      - [GET /fonts/Inter-Bold.woff]
      - [GET /fonts/Inter-Regular.woff] *)
  val middleware: Middleware.t
end

module Impl = struct
  let set_cache_forever_header resp =
    resp |> Response.with_header ~key:"Cache-Control" ~value:"public, immutable, max-age=31536000"

  let set_content_type typ resp =
    resp |> Response.with_header ~key:"Content-Type" ~value:typ

  let get_looksok_css =
    let styles = [
      [%blob "css/01_fonts.css"];
      [%blob "css/02_normalize.css"];
      [%blob "css/03_base.css"];
      [%blob "css/04_forms.css"];
      [%blob "css/05_nav.css"];
    ] in
    Response.(
      ok
      |> set_content_type "text/css"
      |> set_cache_forever_header
      |> with_string_body (String.concat "\n" styles))

  let get_inter_black = Response.(
      ok
      |> set_content_type "font/woff"
      |> set_cache_forever_header
      |> with_string_body [%blob "fonts/Inter-Black.woff"])

  let get_inter_bold = Response.(
      ok
      |> set_content_type "font/woff"
      |> set_cache_forever_header
      |> with_string_body [%blob "fonts/Inter-Bold.woff"])

  let get_inter_regular = Response.(
      ok
      |> set_content_type "font/woff"
      |> set_cache_forever_header
      |> with_string_body [%blob "fonts/Inter-Regular.woff"])

  let middleware handler req =
    match (Request.get_http_method req, Request.get_path req) with
    | ("GET", [ "looksok.css" ]) ->
      Lwt.return get_looksok_css
    | ("GET", [ "fonts"; "Inter-Black.woff" ]) ->
      Lwt.return get_inter_black
    | ("GET", [ "fonts"; "Inter-Bold.woff" ]) ->
      Lwt.return get_inter_bold
    | ("GET", [ "fonts"; "Inter-Regular.woff" ]) ->
      Lwt.return get_inter_regular
    | _ ->
      handler req
end
